@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2004, 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999-2019 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,10 +12,11 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -27,8 +27,6 @@
 int
 main (int argc, const char **argv)
 {
-  char *from;
-  char *subject;
   mu_mailbox_t mbox;
   size_t msgno, total = 0;
   int status;
@@ -50,12 +48,19 @@ main (int argc, const char **argv)
       exit (EXIT_FAILURE);
     }
 
-  mu_mailbox_messages_count (mbox, &total);
+  status = mu_mailbox_messages_count (mbox, &total);
+  if (status != 0)
+    {
+      mu_error ("mu_mailbox_messages_count: %s", mu_strerror (status));
+      exit (EXIT_FAILURE);
+    }
 
   for (msgno = 1; msgno <= total; msgno++)
     {
       mu_message_t msg;
       mu_header_t hdr;
+      const char *from;
+      const char *subject;
 
       if ((status = mu_mailbox_get_message (mbox, msgno, &msg)) != 0
           || (status = mu_message_get_header (msg, &hdr)) != 0)
@@ -64,15 +69,13 @@ main (int argc, const char **argv)
           exit (EXIT_FAILURE);
         }
 
-      if (mu_header_aget_value (hdr, MU_HEADER_FROM, &from))
-        from = strdup ("(NO FROM)");
+      if (mu_header_sget_value (hdr, MU_HEADER_FROM, &from))
+        from = "(NO FROM)";
 
-      if (mu_header_aget_value (hdr, MU_HEADER_SUBJECT, &subject))
-        subject = strdup ("(NO SUBJECT)");
+      if (mu_header_sget_value (hdr, MU_HEADER_SUBJECT, &subject))
+        subject = "(NO SUBJECT)";
 
       printf ("%s\t%s\n", from, subject);
-      free (from);
-      free (subject);
     }
 
   status = mu_mailbox_close (mbox);
