@@ -58,7 +58,7 @@
 static void
 _wsplt_alloc_die (struct mu_wordsplit *wsp)
 {
-  wsp->ws_error (_("memory exhausted"));
+  wsp->ws_error ("%s", _("memory exhausted"));
   abort ();
 }
 
@@ -238,24 +238,24 @@ mu_wordsplit_init (struct mu_wordsplit *wsp, const char *input, size_t len,
 
   if (wsp->ws_flags & MU_WRDSF_ESCAPE)
     {
-      if (!wsp->ws_escape[0])
-	wsp->ws_escape[0] = "";
-      if (!wsp->ws_escape[1])
-	wsp->ws_escape[1] = "";
+      if (!wsp->ws_escape[MU_WRDSX_WORD])
+	wsp->ws_escape[MU_WRDSX_WORD] = "";
+      if (!wsp->ws_escape[MU_WRDSX_QUOTE])
+	wsp->ws_escape[MU_WRDSX_QUOTE] = "";
     }
   else
     {
       if (wsp->ws_flags & MU_WRDSF_CESCAPES)
 	{
-	  wsp->ws_escape[0] = mu_wordsplit_c_escape_tab;
-	  wsp->ws_escape[1] = mu_wordsplit_c_escape_tab;
+	  wsp->ws_escape[MU_WRDSX_WORD] = mu_wordsplit_c_escape_tab;
+	  wsp->ws_escape[MU_WRDSX_QUOTE] = mu_wordsplit_c_escape_tab;
 	  wsp->ws_options |= MU_WRDSO_OESC_QUOTE | MU_WRDSO_OESC_WORD       
 	                     | MU_WRDSO_XESC_QUOTE | MU_WRDSO_XESC_WORD;
 	}
       else
 	{
-	  wsp->ws_escape[0] = "";
-	  wsp->ws_escape[1] = "\\\\\"\"";
+	  wsp->ws_escape[MU_WRDSX_WORD] = "";
+	  wsp->ws_escape[MU_WRDSX_QUOTE] = "\\\\\"\"";
 	  wsp->ws_options |= MU_WRDSO_BSKEEP_QUOTE;
 	}
     }
@@ -1034,9 +1034,14 @@ expvar (struct mu_wordsplit *wsp, const char *str, size_t len,
       rc = mu_wordsplit_find_env (wsp, str, i, &vptr);
       if (rc == MU_WRDSE_OK)
 	{
-	  value = strdup (vptr);
-	  if (!value)
-	    rc = MU_WRDSE_NOSPACE;
+	  if (vptr)
+	    {
+	      value = strdup (vptr);
+	      if (!value)
+		rc = MU_WRDSE_NOSPACE;
+	    }
+	  else
+	    rc = MU_WRDSE_UNDEF;
 	}
       else if (wsp->ws_flags & MU_WRDSF_GETVAR)
 	rc = wsp->ws_getvar (&value, str, i, wsp->ws_closure);
@@ -1113,7 +1118,7 @@ expvar (struct mu_wordsplit *wsp, const char *str, size_t len,
 			wsp->ws_error ("%.*s: %s",
 				       (int) i, str, ws.ws_wordv[0]);
 		      else
-			wsp->ws_error (_("%.*s: %.*s"),
+			wsp->ws_error ("%.*s: %.*s",
 				       (int) i, str, (int) size, defstr);
 		      mu_wordsplit_free (&ws);
 		    }
@@ -1346,6 +1351,7 @@ expcmd (struct mu_wordsplit *wsp, const char *str, size_t len,
   size_t j;
   char *value;
   struct mu_wordsplit_node *newnode;
+  struct mu_wordsplit ws;
   
   str++;
   len--;
@@ -1357,23 +1363,16 @@ expcmd (struct mu_wordsplit *wsp, const char *str, size_t len,
     }
 
   *pend = str + j;
-  if (wsp->ws_options & MU_WRDSO_ARGV)
-    {
-      struct mu_wordsplit ws;
 
-      rc = _wsplt_subsplit (wsp, &ws, str, j,
-			    MU_WRDSF_WS | MU_WRDSF_QUOTE);
-      if (rc)
-	{
-	  _wsplt_seterr_sub (wsp, &ws);
-	  mu_wordsplit_free (&ws);
-	  return 1;
-	}
-      rc = wsp->ws_command (&value, str, j, ws.ws_wordv, wsp->ws_closure);
+  rc = _wsplt_subsplit (wsp, &ws, str, j, MU_WRDSF_WS | MU_WRDSF_QUOTE);
+  if (rc)
+    {
+      _wsplt_seterr_sub (wsp, &ws);
       mu_wordsplit_free (&ws);
+      return 1;
     }
-  else
-    rc = wsp->ws_command (&value, str, j, NULL, wsp->ws_closure);
+  rc = wsp->ws_command (&value, str, j, ws.ws_wordv, wsp->ws_closure);
+  mu_wordsplit_free (&ws);
   
   if (rc == MU_WRDSE_NOSPACE)
     return _wsplt_nomem (wsp);
